@@ -81,6 +81,10 @@ load_printer_list_in_treeview (GtkListStore * store, ManagerDlg * dlg)
     GdkPixbuf *icon = NULL;
 
     printer = printer_el->data;
+    if (g_strrstr (printer->name, "/")) { /* instance ? */
+      printer_el = g_list_next (printer_el);
+      continue;
+    }
     if (printer->type == PRINTER_TYPE_CLASS)
       icon = xfce_icon_theme_load (dlg->icontheme, "printer-class", 48);
     if (!icon || printer->type == PRINTER_TYPE_PRINTER)
