@@ -87,23 +87,11 @@ main (int argc, char **argv)
     mcs_client_add_channel (client, CHANNEL);
 
     if (mcs_client_get_setting (client, "XfPrint/system", CHANNEL, &setting) == MCS_SUCCESS) {
-      if (!load_printing_system (setting->data.v_string))
-        g_error ("Unable to load printing system module %s", setting->data.v_string);
+      if (g_ascii_strcasecmp (setting->data.v_string, "none") != 0  &&
+	  !load_printing_system (setting->data.v_string))
+        g_warning ("Unable to load printing system module %s", setting->data.v_string);
       mcs_setting_free (setting);
     }
-    else {
-      gchar *default_system = NULL;
-
-      g_warning ("No mcs-setting found for XfPrint/system in channel %s, using default printing-system", CHANNEL);
-
-      default_system = g_build_filename (PLUGIN_DIR, "file_plugin.so", NULL);
-
-      if (!load_printing_system (default_system)) {
-        g_error ("Unable to load default printing system module %s", default_system);
-      }
-
-      g_free (default_system);
-    }
 
     mcs_client_destroy (client);
   }
